//
// Crater.cpp
// A crater on the moon.
//
//    Copyright 2002 by Akkana Peck.
// You may use or distribute this code under the terms of the GPL.
//

#include "Crater.h"

#include <math.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

// Static variables:
Crater::Crater() : MoonFeature()
{
}

Crater::Crater(char* name, char* desc, int size,
               int longitude, int latitude)
{
    Init(name, desc, size, longitude, latitude);
}

void
Crater::Init(char* name, char* desc, int size,
             int longitude, int latitude)
{
    MoonFeature::Init(name, desc, size, longitude, latitude);
}

Crater::~Crater()
{
}

// Routines for looping over all known craters:
void
Crater::InitCraters()
{
    if (!sMoonFeatureList)
        return;

    char* craterFileName = DATADIR "craters.dat";
    FILE* cfile = fopen(craterFileName, "r");
    if (!cfile)
        return;

    char line[BUFSIZ];
    while (fgets(line, sizeof line, cfile) != 0)
    {
        if (*line == '#')       // Skip comments
            continue;
        int latitude = (int)atof(line+30);
        if (line[36] == 'S')
            latitude = -latitude;
        int longitude = (int)atof(line+38);
        if (line[44] == 'W')
            longitude = -longitude;
        // Write a null after the name in the line buffer,
        // so we can pass it to strdup:
        int i;
        for (i=28; i>0 && line[i] == ' '; --i)
            ;
        if (i <= 0)
            return;

        line[i+1] = '\0';

        sMoonFeatureList[sNumFeatures++] = new Crater(line, line+56,
                                                      (int)atof(line+47),
                                                      longitude, latitude);
    }
    printf("Craters loaded, %d features\n", sNumFeatures);
}

int Crater::GetSizeX()
{
    return (int)((double)mSize * cos(mLongitude * M_PI / 180.));
}

int Crater::GetSizeY()
{
    return (int)((double)mSize * cos(mLatitude * M_PI / 180.));
}


