//
// MoonMainWin
//
//    Copyright 2002 by Akkana Peck.
// You may use or distribute this code under the terms of the GPL.
//

#include "MoonMainWin.h"

#include "QMoonCanvas.h"

#include <qapplication.h>
#include <qtoolbar.h>
#include <qaction.h>
#include <qmessagebox.h>

#include <stdio.h>

// Included just to get DATADIR -- should separate this.
#include "MoonFeature.h"
#define ICONDIR DATADIR

MoonMainWin::MoonMainWin( QWidget *parent, const char *name )
    : QMainWindow( parent, name ), mZoomLevel(0)
{
    setupToolbar();
    mCanvas = new QMoonCanvas( this, "moonCanvas" );
    setCentralWidget(mCanvas);
}

void MoonMainWin::setupToolbar()
{
    QToolBar* toolbar = new QToolBar(this, "qmoon");
    toolbar->setHorizontalStretchable(TRUE);

    QAction *a;

    a = new QAction("Mirror",
                    QIconSet(QPixmap(ICONDIR "mirror.png")),
                    QString::null, 0, this, 0);
    connect(a, SIGNAL(activated()), SLOT(mirror()));
    a->addTo(toolbar);

    // I don't like any of the standard zoom icons, so provide one:
    a = new QAction("Zoom",
                    QIconSet(QPixmap(ICONDIR "magnify.png")),
                    QString::null, 0, this, 0);
    connect(a, SIGNAL(activated()), SLOT(zoom()));
    a->addTo(toolbar);

    a = new QAction("About", 
                    QIconSet(QPixmap(ICONDIR "about.png")),
                    QString::null, 0, this, 0);
    connect(a, SIGNAL(activated()), SLOT(aboutDialog()));
    a->addTo(toolbar);

    a = new QAction("Quit", 
                    QIconSet(QPixmap(ICONDIR "close.png")),
                    QString::null, 0, this, 0);
    connect(a, SIGNAL(activated()), SLOT(quit()));
    a->addTo(toolbar);
}

MoonMainWin::~MoonMainWin()
{
}

void MoonMainWin::paintEvent(QPaintEvent*)
{
    //printf("MoonMainWin::paintEvent\n");
    mCanvas->Paint();
}

void MoonMainWin::quit()
{
    close();
    //qApp->quit();
}

void MoonMainWin::mirror()
{
    mCanvas->ToggleMirrored();
}

void MoonMainWin::zoom()
{
    mZoomLevel = !mZoomLevel;
    mCanvas->Zoom(mZoomLevel);
    mCanvas->Paint();
}

void MoonMainWin::aboutDialog()
{
    QMessageBox::information(this, "QMoon",
                             "QMoon v. 0.2\n"
                             "Author: Akkana Peck\n"
                             "http://www.shallowsky.com",
                             QMessageBox::Ok);
}
